@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -713,7 +713,7 @@ static integer c__0 = 0;
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int clamswlq_(char *side, char *trans, integer *m, integer *
+/* Subroutine */ void clamswlq_(char *side, char *trans, integer *m, integer *
 	n, integer *k, integer *mb, integer *nb, complex *a, integer *lda, 
 	complex *t, integer *ldt, complex *c__, integer *ldc, complex *work, 
 	integer *lwork, integer *info)
@@ -731,7 +731,7 @@ static integer c__0 = 0;
     extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
     logical notran, lquery;
     integer ctr;
-    extern /* Subroutine */ int cgemlqt_(char *, char *, integer *, integer *,
+    extern /* Subroutine */ void cgemlqt_(char *, char *, integer *, integer *,
 	     integer *, integer *, complex *, integer *, complex *, integer *,
 	     complex *, integer *, complex *, integer *), 
 	    ctpmlqt_(char *, char *, integer *, integer *, integer *, integer 
@@ -799,10 +799,10 @@ static integer c__0 = 0;
 	i__1 = -(*info);
 	xerbla_("CLAMSWLQ", &i__1, (ftnlen)8);
 	work[1].r = (real) lw, work[1].i = 0.f;
-	return 0;
+	return;
     } else if (lquery) {
 	work[1].r = (real) lw, work[1].i = 0.f;
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
@@ -810,7 +810,7 @@ static integer c__0 = 0;
 /* Computing MIN */
     i__1 = f2cmin(*m,*n);
     if (f2cmin(i__1,*k) == 0) {
-	return 0;
+	return;
     }
 
 /* Computing MAX */
@@ -818,7 +818,7 @@ static integer c__0 = 0;
     if (*nb <= *k || *nb >= f2cmax(i__1,*k)) {
 	cgemlqt_(side, trans, m, n, k, mb, &a[a_offset], lda, &t[t_offset], 
 		ldt, &c__[c_offset], ldc, &work[1], info);
-	return 0;
+	return;
     }
 
     if (left && tran) {
@@ -960,7 +960,7 @@ static integer c__0 = 0;
     }
 
     work[1].r = (real) lw, work[1].i = 0.f;
-    return 0;
+    return;
 
 /*     End of CLAMSWLQ */
 
