@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -602,7 +602,7 @@ f"> */
 /* > \ingroup realOTHERauxiliary */
 
 /*  ===================================================================== */
-/* Subroutine */ int sladiv_(real *a, real *b, real *c__, real *d__, real *p, 
+/* Subroutine */ void sladiv_(real *a, real *b, real *c__, real *d__, real *p, 
 	real *q)
 {
     /* System generated locals */
@@ -611,7 +611,7 @@ f"> */
     /* Local variables */
     real s, aa, ab, bb, cc, cd, dd, be, un, ov;
     extern real slamch_(char *);
-    extern /* Subroutine */ int sladiv1_(real *, real *, real *, real *, real 
+    extern /* Subroutine */ void sladiv1_(real *, real *, real *, real *, real 
 	    *, real *);
     real eps;
 
@@ -670,14 +670,14 @@ f"> */
     *p *= s;
     *q *= s;
 
-    return 0;
+    return;
 
 /*     End of SLADIV */
 
 } /* sladiv_ */
 
 /* > \ingroup realOTHERauxiliary */
-/* Subroutine */ int sladiv1_(real *a, real *b, real *c__, real *d__, real *p,
+/* Subroutine */ void sladiv1_(real *a, real *b, real *c__, real *d__, real *p,
 	 real *q)
 {
     real r__, t;
@@ -700,7 +700,7 @@ f"> */
     *a = -(*a);
     *q = sladiv2_(b, a, c__, d__, &r__, &t);
 
-    return 0;
+    return;
 
 /*     End of SLADIV1 */
 
