@@ -52,9 +52,6 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
-typedef char logical1;
 typedef char integer1;
 
 #define TRUE_ (1)
@@ -259,7 +256,7 @@ typedef struct Namelist Namelist;
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 
 
 /* Table of constant values */
